==> goods-center-api-2.9.104-sources.jar: cn/com/duiba/goods/center/api/remoteservice/RemoteAppItemClassifyService.java <==
package cn.com.duiba.goods.center.api.remoteservice;

import cn.com.duiba.api.bo.page.Page;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.goods.center.api.remoteservice.dto.AppItemClassifyDto;
import cn.com.duiba.goods.center.api.remoteservice.dto.AppItemClassifyRelationDto;
import cn.com.duiba.wolf.dubbo.DubboResult;
import org.javatuples.Pair;

import java.util.List;
import java.util.Map;

/**
 * Created by xiaoxuda on 2016/11/17.
 */
@AdvancedFeignClient
public interface RemoteAppItemClassifyService {
    /**
     * 根据id查询商品分类信息
     * @param id
     * @return
     */
    public DubboResult<AppItemClassifyDto> find(Long id);

    /**
     * 删除relation
     * @param appItemId
     * @return
     */
    public DubboResult<Integer> deleteRelationAppItem(Long appItemId);

    /**
     * findByIds
     * @param ids
     * @return
     */
    List<AppItemClassifyDto> findByIds(List<Long> ids);

    /**
     * findAllByAppId
     * @param appId
     * @return
     */
    List<AppItemClassifyDto> findAllByAppId(Long appId);

    /**
     * update
     * @param appItemClassifyDto
     */
    public void update(AppItemClassifyDto appItemClassifyDto);


    /**
     * 自定义分类商品排序
     */
    public void sortByClassifyPayload(Long classifyId, Long appItemId,Long operatingActivityId ,Integer startPayload, Integer endPayload);

    /**
     * 自定义分类商品置顶
     */
    public void setTop(Long classifyId, Long appItemId,Long operatingActivityId);

    /**
     * 自定义分类商品取消置顶
     */
    public void cancleTop(Long classifyId, Long appItemId,Long operatingActivityId);

    public Long findByCount(Map<String, Object> params);

    public List<AppItemClassifyDto> findByLimit(Map<String, Object> params);

    public Integer deleteClassifyAllAppItem(Long classifyId);

    public int deleteClassifyAppItem(Long classifyId, Long appItemId);

    public int batchInsert(List<Map<String, Object>> classifyRelation);

    public List<Long> findAllAppItemById(Long classifyId);

    public int deleteAppItemRelation(List<Long> ids, Long appId);

    public void insert(AppItemClassifyDto appItemClassifyDO);

    public Integer findMaxPayload(Long classifyId);

    public Integer updatePayload(Long appItemId, Long classifyId, Integer payload);


    /**
     * 查询开发者分类总数
     * @param appId
     * @return
     */
    Long findByCountNew(Long appId);

    /**
     * 分页查询分类列表
     * @param appId
     * @param start
     * @param pageSize
     * @return
     */
    List<AppItemClassifyDto> findByLimitNew(Long appId, int start, int pageSize);


    /**
     * 分页查询分类列表
     * @param appId
     * @param name
     * @param offset
     * @param max
     * @return
     */
    Page<AppItemClassifyDto> findByLimitNewByAppAndName(Long appId, String name, int offset, int max);

    /**
     * 根据分类id查询分类下所有商品活动
     * @param classifyId
     * @return
     */
    List<AppItemClassifyRelationDto> getByClassifyId(Long classifyId);

    /**
     * 删除关联的活动
     * @param classifyId
     * @param operatingActivityId
     * @return
     */
    int deleteClassifyActivity(Long classifyId, Long operatingActivityId);


    /**
     * 批量删除关联的活动
     * @param ids
     * @param appId
     * @return
     */
    int deleteActivityRelation(List<Long> ids, Long appId);

    /**
     * 根据分类id找出所有的活动id
     * @param classifyId
     * @return
     */
    List<Long> findAllOpActivityIdById(Long classifyId);

    /**
     * 自定义分类排序
     * @param classifyId
     * @param pairs type-id映射
     */
    void sortClassify(Long classifyId, List<Pair<Integer, Long>> pairs);

    List<AppItemClassifyRelationDto> getByAppItemId(List ids);

    /**
     * 批量删除关联的商品
     *
     * @param classifyId
     * @param appItemIds
     * @return
     */
    int batchDeleteClassifyAppItem(Long classifyId, List<Long> appItemIds);

    /**
     * 批量删除关联的活动
     *
     * @param classifyId
     * @param operatingActivityIds
     * @return
     */
    int batchDeleteClassifyActivity(Long classifyId, List<Long> operatingActivityIds);

    /**
     * 批量删除
     *
     * @param keys
     * @return
     */
    int batchDeleteRelation(List<AppItemClassifyRelationDto> keys);

    /**
     * 批量查询最大排序
     *
     * @param classifyIds
     * @return
     */
    Map<Long, Integer> findMaxPayloadByClassifyIds(List<Long> classifyIds);

    /**
     * 根据分类id列表查询所有关联商品
     *
     * @param classifyIds
     * @return
     */
    List<AppItemClassifyRelationDto> findByClassifyIds(List<Long> classifyIds);

    /**
     * 根据分类id和商品id列表查询
     *
     * @param classifyId
     * @param appItemIds
     * @return
     */
    List<AppItemClassifyRelationDto> findByClassifyIdAndAppItemIds(Long classifyId, List<Long> appItemIds);

    /**
     * 获取分组下置顶商品最大排序值
     *
     * @param classifyId
     * @return
     */
    Integer findMaxTopPayload(Long classifyId);

    /**
     * 获取分组下置顶商品最小排序值
     *
     * @param classifyId
     * @return
     */
    int findMinTopPayload(Long classifyId);

    /**
     * 批量增加分组下指定排序值之后的排序值
     *
     * @param classifyId
     * @param minPayload 最小排序值，会对 大于等于 该值的记录 排序值+1
     */
    void batchIncreasePayload(Long classifyId, int minPayload);

    /**
     * 批量减少分组下指定排序值之前的排序值
     *
     * @param classifyId
     * @param maxPayload 最大排序值，会对 小于等于 该值的记录 排序值-1
     */
    void batchDecreasePayload(Long classifyId, int maxPayload);

    /**
     * 批量增加分组下置顶商品指定排序值之后的排序值
     *
     * @param classifyId
     * @param minPayload 最小排序值，会对 大于等于 该值的记录 排序值+1
     */
    void batchIncreasePayload4Top(Long classifyId, int minPayload);

    /**
     * 批量减少分组下置顶商品指定排序值之前的排序值
     *
     * @param classifyId
     * @param maxPayload 最大排序值，会对 小于等于 该值的记录 排序值-1
     */
    void batchDecreasePayload4Top(Long classifyId, int maxPayload);

    /**
     * 更新排序值
     *
     * @param classifyId
     * @param appItemId
     * @param payload
     */
    void updateTopPayload(Long classifyId, Long appItemId, Integer payload);

    /**
     * 批量增加分组下中转排序字段指定排序值之后的排序值
     *
     * @param classifyId
     * @param minPayload 最小排序值，会对 大于等于 该值的记录 排序值+1
     */
    @Deprecated
    void batchIncreaseTopPayload(Long classifyId, int minPayload);

    /**
     * 批量减少分组下中转排序字段指定排序值之前的排序值
     *
     * @param classifyId
     * @param maxPayload 最大排序值，会对 小于等于 该值的记录 排序值-1
     */
    @Deprecated
    void batchDecreaseTopPayload(Long classifyId, int maxPayload);
}

==> goods-center-api-3.0.13-sources.jar: cn/com/duiba/goods/center/api/remoteservice/RemoteAppItemClassifyService.java <==
package cn.com.duiba.goods.center.api.remoteservice;

import cn.com.duiba.api.bo.page.Page;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.goods.center.api.remoteservice.dto.AppItemClassifyDto;
import cn.com.duiba.goods.center.api.remoteservice.dto.AppItemClassifyRelationDto;
import cn.com.duiba.wolf.dubbo.DubboResult;
import org.javatuples.Pair;

import java.util.List;
import java.util.Map;

/**
 * Created by xiaoxuda on 2016/11/17.
 */
@AdvancedFeignClient
public interface RemoteAppItemClassifyService {
    /**
     * 根据id查询商品分类信息
     * @param id
     * @return
     */
    public DubboResult<AppItemClassifyDto> find(Long id);

    /**
     * 删除relation
     * @param appItemId
     * @return
     */
    public DubboResult<Integer> deleteRelationAppItem(Long appItemId);

    /**
     * findByIds
     * @param ids
     * @return
     */
    List<AppItemClassifyDto> findByIds(List<Long> ids);

    /**
     * findAllByAppId
     * @param appId
     * @return
     */
    List<AppItemClassifyDto> findAllByAppId(Long appId);

    /**
     * update
     * @param appItemClassifyDto
     */
    public void update(AppItemClassifyDto appItemClassifyDto);


    /**
     * 自定义分类商品排序
     */
    public void sortByClassifyPayload(Long classifyId, Long appItemId,Long operatingActivityId ,Integer startPayload, Integer endPayload);

    /**
     * 自定义分类商品置顶
     */
    public void setTop(Long classifyId, Long appItemId,Long operatingActivityId);

    /**
     * 自定义分类商品取消置顶
     */
    public void cancleTop(Long classifyId, Long appItemId,Long operatingActivityId);

    public Long findByCount(Map<String, Object> params);

    public List<AppItemClassifyDto> findByLimit(Map<String, Object> params);

    public Integer deleteClassifyAllAppItem(Long classifyId);

    public int deleteClassifyAppItem(Long classifyId, Long appItemId);

    public int batchInsert(List<Map<String, Object>> classifyRelation);

    public List<Long> findAllAppItemById(Long classifyId);

    public int deleteAppItemRelation(List<Long> ids, Long appId);

    public void insert(AppItemClassifyDto appItemClassifyDO);

    public Integer findMaxPayload(Long classifyId);

    public Integer updatePayload(Long appItemId, Long classifyId, Integer payload);


    /**
     * 查询开发者分类总数
     * @param appId
     * @return
     */
    Long findByCountNew(Long appId);

    /**
     * 分页查询分类列表
     * @param appId
     * @param start
     * @param pageSize
     * @return
     */
    List<AppItemClassifyDto> findByLimitNew(Long appId, int start, int pageSize);


    /**
     * 分页查询分类列表
     * @param appId
     * @param name
     * @param offset
     * @param max
     * @return
     */
    Page<AppItemClassifyDto> findByLimitNewByAppAndName(Long appId, String name, int offset, int max);

    /**
     * 根据分类id查询分类下所有商品活动
     * @param classifyId
     * @return
     */
    List<AppItemClassifyRelationDto> getByClassifyId(Long classifyId);

    /**
     * 删除关联的活动
     * @param classifyId
     * @param operatingActivityId
     * @return
     */
    int deleteClassifyActivity(Long classifyId, Long operatingActivityId);


    /**
     * 批量删除关联的活动
     * @param ids
     * @param appId
     * @return
     */
    int deleteActivityRelation(List<Long> ids, Long appId);

    /**
     * 根据分类id找出所有的活动id
     * @param classifyId
     * @return
     */
    List<Long> findAllOpActivityIdById(Long classifyId);

    /**
     * 自定义分类排序
     * @param classifyId
     * @param pairs type-id映射
     */
    void sortClassify(Long classifyId, List<Pair<Integer, Long>> pairs);

    List<AppItemClassifyRelationDto> getByAppItemId(List ids);

    /**
     * 批量删除关联的商品
     *
     * @param classifyId
     * @param appItemIds
     * @return
     */
    int batchDeleteClassifyAppItem(Long classifyId, List<Long> appItemIds);

    /**
     * 批量删除关联的活动
     *
     * @param classifyId
     * @param operatingActivityIds
     * @return
     */
    int batchDeleteClassifyActivity(Long classifyId, List<Long> operatingActivityIds);

    /**
     * 批量删除
     *
     * @param keys
     * @return
     */
    int batchDeleteRelation(List<AppItemClassifyRelationDto> keys);

    /**
     * 批量查询最大排序
     *
     * @param classifyIds
     * @return
     */
    Map<Long, Integer> findMaxPayloadByClassifyIds(List<Long> classifyIds);

    /**
     * 根据分类id列表查询所有关联商品
     *
     * @param classifyIds
     * @return
     */
    List<AppItemClassifyRelationDto> findByClassifyIds(List<Long> classifyIds);

    /**
     * 根据分类id和商品id列表查询
     *
     * @param classifyId
     * @param appItemIds
     * @return
     */
    List<AppItemClassifyRelationDto> findByClassifyIdAndAppItemIds(Long classifyId, List<Long> appItemIds);

    /**
     * 获取分组下置顶商品最大排序值
     *
     * @param classifyId
     * @return
     */
    Integer findMaxTopPayload(Long classifyId);

    /**
     * 获取分组下置顶商品最小排序值
     *
     * @param classifyId
     * @return
     */
    int findMinTopPayload(Long classifyId);

    /**
     * 批量增加分组下指定排序值之后的排序值
     *
     * @param classifyId
     * @param minPayload 最小排序值，会对 大于等于 该值的记录 排序值+1
     */
    void batchIncreasePayload(Long classifyId, int minPayload);

    /**
     * 批量减少分组下指定排序值之前的排序值
     *
     * @param classifyId
     * @param maxPayload 最大排序值，会对 小于等于 该值的记录 排序值-1
     */
    void batchDecreasePayload(Long classifyId, int maxPayload);

    /**
     * 批量增加分组下置顶商品指定排序值之后的排序值
     *
     * @param classifyId
     * @param minPayload 最小排序值，会对 大于等于 该值的记录 排序值+1
     */
    void batchIncreasePayload4Top(Long classifyId, int minPayload);

    /**
     * 批量减少分组下置顶商品指定排序值之前的排序值
     *
     * @param classifyId
     * @param maxPayload 最大排序值，会对 小于等于 该值的记录 排序值-1
     */
    void batchDecreasePayload4Top(Long classifyId, int maxPayload);

    /**
     * 更新排序值
     *
     * @param classifyId
     * @param appItemId
     * @param payload
     */
    void updateTopPayload(Long classifyId, Long appItemId, Integer payload);

    /**
     * 批量增加分组下中转排序字段指定排序值之后的排序值
     *
     * @param classifyId
     * @param minPayload 最小排序值，会对 大于等于 该值的记录 排序值+1
     */
    @Deprecated
    void batchIncreaseTopPayload(Long classifyId, int minPayload);

    /**
     * 批量减少分组下中转排序字段指定排序值之前的排序值
     *
     * @param classifyId
     * @param maxPayload 最大排序值，会对 小于等于 该值的记录 排序值-1
     */
    @Deprecated
    void batchDecreaseTopPayload(Long classifyId, int maxPayload);

    /**
     * 查询当前商品关联分组其他商品id
     * @param appItemIds
     * @param num
     * @return
     */
    List<Long> selectRecommendAppItemIdsByClassify(List<Long> appItemIds, Integer num);
}
